@@ -57,7 +57,6 @@ load_pkgs(){
     local packages_root
     local packages_live
     local packages_root_init
-    local packages_live_init
 
     local common_key_init=".packages-init.${INITSYS}[]"
     local root_key_init=".rootfs.packages-init.${INITSYS}[]"
@@ -70,12 +69,12 @@ load_pkgs(){
             msg2 "Loading Packages: [%s] ..." "common.packages-base"
             mapfile -t common_base < <(yq -P '.packages-base[]' "$common_yaml")
 
-            msg2 "Loading Packages: [%s] ..." "common.packages-apps"
-            mapfile -t common_apps < <(yq -P '.packages-apps[]' "$common_yaml")
-
             msg2 "Loading Packages: [%s] ..." "common.packages-init.${INITSYS}"
             mapfile -t common_init < <(common_key_init="$common_key_init" yq -P 'eval(strenv(common_key_init))' "$common_yaml")
 
+            msg2 "Loading Packages: [%s] ..." "common.packages-apps"
+            mapfile -t common_apps < <(yq -P '.packages-apps[]' "$common_yaml")
+
             if "${HAS_LIVE}"; then
                 if ${USE_XLIBRE}; then
                     msg2 "Loading Packages: [%s] ..." "common.packages-xlibre"
@@ -94,8 +93,8 @@ load_pkgs(){
 
             packages+=(
                 "${common_base[@]}"
-                "${common_apps[@]}"
                 "${common_init[@]}"
+                "${common_apps[@]}"
                 "${packages_root[@]}"
                 "${packages_root_init[@]}"
             )
@@ -105,25 +104,13 @@ load_pkgs(){
                     "${common_xorg}"
                 )
             fi
-
-            for svc in "${SERVICES[@]}"; do
-                case "$svc" in
-                    sddm|gdm|lightdm|mdm|greetd|lxdm|xdm)
-                        display_manager="$svc"
-                    ;;
-                esac
-            done
         ;;
         livefs)
             msg2 "Loading Packages: [%s] ..." "livefs.packages"
             mapfile -t packages_live < <(yq -P '.livefs.packages[]' "$profile_yaml")
 
-            msg2 "Loading Packages: [%s] ..." "livefs.packages-init.${INITSYS}"
-            mapfile -t packages_live_init < <(live_key_init="$live_key_init" yq -P 'eval(strenv(live_key_init))' "$profile_yaml")
-
             packages+=(
                 "${packages_live[@]}"
-                "${packages_live_init[@]}"
             )
         ;;
         bootfs)
